#[repr(C)]
pub struct GstMemory {
pub mini_object: GstMiniObject,
pub allocator: *mut GstAllocator,
pub parent: *mut GstMemory,
pub maxsize: size_t,
pub align: size_t,
pub offset: size_t,
pub size: size_t,
}
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.